FancyColor extension
- on
Properties
- contrastColor → Color
-
Available on Color, provided by the FancyColor extension
A pure Color contrasting with this one (i.e., Colors.black or Colors.white), depending on the estimatedBrightness.no setter - contrastSystemUiOverlayStyle → SystemUiOverlayStyle
-
Available on Color, provided by the FancyColor extension
The SystemUiOverlayStyle providing the most contrast on this color.no setter - estimatedBrightness → Brightness
-
Available on Color, provided by the FancyColor extension
Returns the estimated Brightness of this color based on its luminance.no setter - hsl → HSLColor
-
Available on Color, provided by the FancyColor extension
Shortcut forHSLColor.fromColor(color).no setter - hsv → HSVColor
-
Available on Color, provided by the FancyColor extension
Shortcut forHSVColor.fromColor(color).no setter - isDark → bool
-
Available on Color, provided by the FancyColor extension
trueif the estimatedBrightness is Brightness.dark,falseotherwise.no setter - isLight → bool
-
Available on Color, provided by the FancyColor extension
trueif the estimatedBrightness is Brightness.light,falseotherwise.no setter - isOpaque → bool
-
Available on Color, provided by the FancyColor extension
trueif this color is fully opaque, i.e. has an a of1.0.no setter
Methods
-
alphaBlendOn(
Color background) → Color -
Available on Color, provided by the FancyColor extension
Shortcut forColor.alphaBlend(color, background). -
withAdditionalAlpha(
double alpha) → Color -
Available on Color, provided by the FancyColor extension
Applyalphain addition to the existing opacity by multiplying them.