FancyOutlinedButton class

In addition to a normal OutlinedButton, this Widget natively supports disabling it and showing a loading state.

Inheritance

Constructors

FancyOutlinedButton({Key? key, bool? isEnabled, required VoidCallback? onPressed, required Widget child, bool isLoading = false, Widget? loadingChild, Widget? loadingIndicator, ButtonStyle? style})
Creates an OutlinedButton.
const
FancyOutlinedButton.icon({Key? key, bool? isEnabled, required VoidCallback? onPressed, required Widget icon, required Widget label, bool isLoading = false, Widget? loadingLabel, Widget? loadingIndicator, ButtonStyle? style})
Creates an OutlinedButton with a leading icon.
const

Properties

actualChild → Widget
no setterinherited
actualLoadingChild → Widget
no setterinherited
actualLoadingIndicator → Widget
no setterinherited
actualOnPressed → VoidCallback?
no setterinherited
child → Widget
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
icon → Widget?
finalinherited
isActuallyEnabled → bool
no setterinherited
isEnabled → bool?
finalinherited
isLoading → bool
finalinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingChild → Widget?
finalinherited
loadingIndicator → Widget?
finalinherited
loadingIndicatorSize → double
no setterinherited
onPressed → VoidCallback?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → ButtonStyle?
finalinherited

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited