MaterialColors extension
- on
Properties
- disabledOnColor → Color
-
Available on Color, provided by the MaterialColors extension
The Material Design disabled color contrasting with this color.no setter - highEmphasisOnColor → Color
-
Available on Color, provided by the MaterialColors extension
The Material Design high emphasis color contrasting with this color.no setter - mediumEmphasisOnColor → Color
-
Available on Color, provided by the MaterialColors extension
The Material Design medium emphasis color contrasting with this color.no setter - withDisabledOpacity → Color
-
Available on Color, provided by the MaterialColors extension
The Material Design disabled version with this color.no setter - withHighEmphasisOpacity → Color
-
Available on Color, provided by the MaterialColors extension
The Material Design high emphasis version with this color.no setter - withMediumEmphasisOpacity → Color
-
Available on Color, provided by the MaterialColors extension
The Material Design medium emphasis version with this color.no setter
Constants
- disabledTextAlpha → const double
- Alpha value for Material Design disabled text.
- highEmphasisTextAlpha → const double
- Alpha value for Material Design high-emphasis text.
- mediumEmphasisTextAlpha → const double
- Alpha value for Material Design medium-emphasis text.